@@ -1,4 +1,4 @@
-from .problem import Problem
+from .problem import problem
 from .backbone_autograd import backbone_autograd
 
 
