@@ -18,6 +18,8 @@ from torch.nn.modules.utils import _single, _pair, _triple, _reverse_repeat_tupl
 # from torch._torch_docs import reproducibility_notes
 from torch.nn.common_types import _size_1_t, _size_2_t, _size_3_t
 
+from ..utils.modified_apply import modified_apply
+
 
 def wvt_conv_flatten(tensor_shape):
     tensor_shape_ref = (tensor_shape[1], tensor_shape[0], *tensor_shape[2:]  )
@@ -156,14 +158,16 @@ class _ConvNd_cdopt(nn.Module):
 
                 
         self.weight_to_var, self.var_to_weight, self.var_shape = weight_var_transfer(self.weight.size())
-
+        
+        
         self.manifold = manifold_class(self.var_shape, device=device, dtype= dtype, **manifold_args)
         self.A = lambda X_tensor: self.var_to_weight(self.manifold.A( self.weight_to_var(X_tensor) ))
         self.C = lambda X_tensor: self.manifold.C( self.weight_to_var(X_tensor) )
         self.feasibility = lambda : torch.linalg.norm( self.C(self.weight).flatten() )
         self.quad_penalty = lambda : torch.sum( self.C(self.weight) **2 )
         for key, param in self.manifold._parameters.items():
-            self._parameters[key] = param
+            # self._parameters[key] = param
+            self.register_buffer(key, param, persistent=False)
 
         self.reset_parameters()
 
@@ -203,6 +207,10 @@ class _ConvNd_cdopt(nn.Module):
         if not hasattr(self, 'padding_mode'):
             self.padding_mode = 'zeros'
 
+    def _apply(self, fn):
+        return modified_apply(self, fn)
+    
+
 
 
 class Conv1d_cdopt(_ConvNd_cdopt):
